**************************************
Welcome to handyscope's documentation!
**************************************

Handyscope provides a Python interface to the mobile USB-oscilloscopes made by TiePie.


Contents
========

.. toctree::
   :maxdepth: 2

   readme
   api
   authors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
